@@ -14,19 +14,25 @@ test_that("REQ PLAIN", {
   )
 
   write_parquet(d, tmp, compression = "uncompressed")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_snapshot({
     tapply(pgs$num_values, pgs$column + 1, sum)
   })
   expect_equal(as.data.frame(read_parquet(tmp)), d)
 
   write_parquet(d, tmp, compression = "snappy")
-  pgs <- parquet_pages(tmp)
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_snapshot({
     tapply(pgs$num_values, pgs$column + 1, sum)
   })
   expect_equal(as.data.frame(read_parquet(tmp)), d)
+
+  # data page v2
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "uncompressed")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2))
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
 })
 
 test_that("OPT PLAIN", {
@@ -45,19 +51,24 @@ test_that("OPT PLAIN", {
   )
 
   write_parquet(d, tmp, compression = "uncompressed")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_snapshot({
     tapply(pgs$num_values, pgs$column + 1, sum)
   })
-  d2 <- read_parquet(tmp)
   expect_equal(as.data.frame(read_parquet(tmp)), d)
 
   write_parquet(d, tmp, compression = "snappy")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_snapshot({
     tapply(pgs$num_values, pgs$column + 1, sum)
   })
   expect_equal(as.data.frame(read_parquet(tmp)), d)
+
+  # data page v2
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "uncompressed")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2))
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
 })
 
 test_that("REQ RLE_DICT", {
@@ -73,14 +84,24 @@ test_that("REQ RLE_DICT", {
   )
 
   write_parquet(d, tmp, compression = "uncompressed")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_equal(sum(pgs$num_values[pgs$page_type == "DATA_PAGE"]), nrow(d))
   expect_equal(as.data.frame(read_parquet(tmp)), d)
 
   write_parquet(d, tmp, compression = "snappy")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_equal(sum(pgs$num_values[pgs$page_type == "DATA_PAGE"]), nrow(d))
   expect_equal(as.data.frame(read_parquet(tmp)), d)
+
+  # data page v2
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "uncompressed")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "snappy")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "gzip")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "zstd")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
 })
 
 test_that("OPT RLE_DICT", {
@@ -96,14 +117,24 @@ test_that("OPT RLE_DICT", {
   )
 
   write_parquet(d, tmp, compression = "uncompressed")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_equal(sum(pgs$num_values[pgs$page_type == "DATA_PAGE"]), nrow(d))
   expect_equal(as.data.frame(read_parquet(tmp)), d)
 
   write_parquet(d, tmp, compression = "snappy")
-  pgs <- parquet_pages(tmp)
+  pgs <- read_parquet_pages(tmp)
   expect_equal(sum(pgs$num_values[pgs$page_type == "DATA_PAGE"]), nrow(d))
   expect_equal(as.data.frame(read_parquet(tmp)), d)
+
+  # data page v2
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "uncompressed")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "snappy")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "gzip")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
+  write_parquet(d, tmp, options = parquet_options(write_data_page_version = 2), compression = "zstd")
+  expect_equal(as.data.frame(read_parquet(tmp)), d)
 })
 
 test_that("write_parquet() to memory", {
@@ -118,6 +149,24 @@ test_that("write_parquet() to memory", {
   expect_equal(pm, pm2)
 })
 
+test_that("write_parquet() to memory 2", {
+  # https://github.com/r-lib/nanoparquet/issues/77
+  data <- data.frame(
+    TEST_1 = seq(as.Date("2000/1/1"), by = "day", length.out = 100000),
+    TEST_2 = seq(1:100000),
+    TEST_3 = seq(as.Date("1990/1/1"), by = "day", length.out = 100000),
+    TEST_2 = seq(100000:1)
+  )
+
+  tmp <- tempfile(fileext = ".parquet")
+  on.exit(unlink(tmp), add = TRUE)
+
+  r1 <- write_parquet(data, ":raw:")
+  write_parquet(data, tmp)
+  r2 <- readBin(tmp, what = "raw", file.size(tmp))
+  expect_equal(r1, r2)
+})
+
 test_that("gzip compression", {
   d <- test_df(missing = TRUE)
   tmp <- tempfile(fileext = ".parquet")
